@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Rope::Object;
 my (%META, %PRO);
@@ -50,9 +50,9 @@ BEGIN {
 				}
 			} else {
 				$META{$caller}{properties}{$prop} = {
-					%options,
 					class => $caller,
-					index => ++$META{$caller}{keys}
+					index => ++$META{$caller}{keys},	
+					%options
 				};
 			}
 		},
@@ -321,7 +321,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
